@@ -15,7 +15,7 @@ class Secrets:
     item_iows_contract = "37249"
     purchases_x_client_id = "af2525c3-1779-49be-8d7d-adf32cac1934"
     purchases_checkout_x_client_id = "6a38e438-0bbb-4d4f-bc55-eb314c2e8e23"
-    auth_guest_token_x_client_id = "e026b58d-dd69-425f-a67f-1e9a5087b87b"
-    auth_guest_token_x_client_secret = (
+    auth_guest_token_x_client_id = "e026b58d-dd69-425f-a67f-1e9a5087b87b"  # nosec
+    auth_guest_token_x_client_secret = (  # nosec
         "cP0vA4hJ4gD8kO3vX3fP2nE6xT7pT3oH0gC5gX6yB4cY7oR5mB"
     )
